@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11376 2019-03-03 14:21:00Z Lavender $
+# $Id: build_boilerplate2.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
-# $Revision: 11376 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import re
@@ -67,7 +67,7 @@ BLOCK_TAGS = ['div',]
 # special ----------------------------------------------------------------------
 SKIP_BLOCK_TAG = ['a', 'span',] + VISUAL_TAGS
 
-if cms.__version__.startswith('3.5'):
+if not cms.__version__.startswith('3.4'):
     ADD_COMMENT_TO_PREVIOUS = []
 else:    
     ADD_COMMENT_TO_PREVIOUS = ['img', 'a',]
@@ -110,6 +110,7 @@ class Command(BaseCommand):
     args = '<destination folder>'
 
     def add_arguments(self, parser):
+        parser.add_argument('path', type=str, help="template folder")
         parser.add_argument(
             '-d', '--debug', 
             action='store_false',
@@ -117,10 +118,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         try:
-            if len(args) < 1:
-                path = TEMPLATES_DIR_PATH
-            else:
-                path = args[0]
+            path = options['path']
 
             debug = options['debug']
 
@@ -511,7 +509,7 @@ class Command(BaseCommand):
             head.insert(0, metaDescription)
         head.insert(0, comment) 
         head.insert(0, addJ)
-        if not cms.__version__.startswith('3.5'):
+        if cms.__version__.startswith('3.4'):
             head.insert(0, addContext)
         head.insert(0, workAroundComment)
         head.insert(0, jq)
